@@ -1,3 +1,6 @@
+from os import remove
+from os.path import basename, dirname, join
+
 from .lexer import tokenize_file
 
 
@@ -6,6 +9,8 @@ class File:
     def __init__(self, filename):
         self.filename = filename
         self.tokens = tokenize_file(filename)
+        self.new_filename = basename(filename)
+        self.packages = []
 
     def __repr__(self):
         return self.filename
@@ -14,6 +19,9 @@ class File:
         return str(self.filename)
 
     def print_file(self):
+        remove(self.filename)
+        self.filename = join(dirname(self.filename), self.new_filename)
         file = open(self.filename, mode="w", encoding='utf-8')
         for token in self.tokens:
             file.write(token.second_value)
+        file.close()
