@@ -1,5 +1,7 @@
 import logging
 import re
+from os import chdir, listdir, rename
+from os.path import dirname
 from pathlib import Path
 
 from .lexer import TokenType, Token, Position
@@ -33,6 +35,18 @@ def validate(files):
                              f'expected {token.second_value}, actual {token.value}')
 
 
+def rename_dirs(files):
+    for file in files:
+        chdir(dirname(file.filename))
+        for package in file.packages:
+            chdir('..')
+            if package[0] in listdir():
+                if package[0] != package[1]:
+                    rename(package[0], package[1])
+            else:
+                break
+
+
 def fix(files):
     format_files(files)
     logging.basicConfig(filename='fixing.log', level=logging.WARN)
@@ -42,6 +56,7 @@ def fix(files):
                 logging.warn(f'{file.filename}\t {token.position.row}:{token.position.column}\t replace '
                              f'{token.value} -> {token.second_value}')
     print_files(files)
+    rename_dirs(files)
 
 
 class_interface_enum = ('class', 'interface', 'enum', '@interface')
@@ -77,7 +92,6 @@ class Formatter:
         return -1
 
     def replace_all_tokens_like_this(self, token):
-        print(token)
         for file in self.files:
             for file_token in file.tokens:
                 if file_token.value == token.value:
@@ -130,6 +144,16 @@ class Formatter:
 
         self.replace_all_tokens_like_this(token)
 
+    @staticmethod
+    def fix_filename(file):
+        filename = Token(TokenType.identifier, file.new_filename)
+
+        if Formatter.is_upper_case(filename):
+            file.new_filename = file.new_filename.lower()
+
+        Formatter.replace_underscore_to_uppercase(filename)
+        file.new_filename = Formatter.to_upper(filename.second_value, 0)
+
     @staticmethod
     def is_camel_case_first_down(token):
         return re.search('^[a-z][a-zA-Z0-9]*$', token.second_value)
@@ -182,6 +206,11 @@ class Formatter:
             return True
         return token.value in ('void', 'byte', 'int', 'boolean', 'char', 'long', 'short')
 
+
+    def replace_to_snake_case(self, token):
+        self.replace_to_upper_case(token)
+        token.second_value = token.second_value.lower()
+
     # fix
     def fix_names(self, file):
         stack = []
@@ -189,6 +218,14 @@ class Formatter:
         while i < len(file.tokens):
             token = file.tokens[i]
 
+            if token.value == 'package':
+                while token.value != ';':
+                    i += 1
+                    token = file.tokens[i]
+                    if token.token_type == TokenType.identifier:
+                        self.replace_to_snake_case(token)
+                        file.packages.insert(0, (token.value, token.second_value))
+
             if token.value in class_interface_enum and \
                     file.tokens[Formatter.get_next_no_whitespace_token_id(file, i)].token_type == TokenType.identifier:
                 stack.append(token.value)
@@ -263,7 +300,6 @@ class Formatter:
         i = 3
         while i + 2 < len(token.second_value):
             char = token.second_value[i]
-            next_char = token.second_value[i + 1]
             if char == '\n':
                 second_part = token.second_value[i:]
                 local_i = 0
@@ -567,3 +603,4 @@ class Formatter:
             print(file)
             self.fix_names(file)
             Formatter.fix_comments(file)
+            Formatter.fix_filename(file)
